# Intro

This repo contains methods, objects and utilities for EDA and deep learning. Most of it is designed for deep learning tasks on top of PyTorch.

Example usages:

```
pip install devai
```

Or

```
git clone https://github.com/devkosal/devai
cd devai
pip install -e .
```
